@@ -1,7 +1,7 @@
 /*
  * asapm is the APM (Advanced Power Management) monitor utility for X Windows
- * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
- * For the updates see http://bewoner.dma.be/Albert/linux/
+ * Copyright (c) 1998-2000  Albert "Tigr" Dorofeev <albert@tigr.net>
+ * For the updates see http://www.tigr.net/
  *
  * This software is distributed under GPL. For details see LICENSE file.
  */
@@ -10,6 +10,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <math.h>
+#include <sys/time.h>
 #include "state.h"
 #include "apm_read.h"
 #include "apm_x.h"
@@ -108,7 +110,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asapm : Advanced Power Management monitor version 2.9\n");
+        printf("asapm : Advanced Power Management monitor version 2.10\n");
 }               
 
 /*
@@ -245,8 +247,10 @@ void    parsecmdline(int argc, char *argv[])
 
 int main(int argc, char *argv[])
 {
-        unsigned long x11_2_apm;
-        unsigned long interval_counter = 0;
+	struct timeval tp;
+	struct timezone tzp;
+
+	long old_time, new_time;
 
 	defaults();
 	parsecmdline(argc, argv);
@@ -275,12 +279,20 @@ int main(int argc, char *argv[])
 		return 1;
 	}
         /* Handle the X events and check the APM state in a loop */
-        x11_2_apm = state.apm_interval / state.x11_interval; 
-        interval_counter = 0; 
+
+	gettimeofday(&tp, &tzp);
+	old_time = tp.tv_sec;
+
         while (1) {
-                if ( ++interval_counter >= x11_2_apm ) {
-                        interval_counter = 0;
-                        CheckAPMEvents();
+         	gettimeofday(&tp, &tzp);
+		if ( tp.tv_sec != old_time ) {
+			new_time = tp.tv_sec;
+			if ( abs(new_time - old_time ) >= 
+					(state.apm_interval / 1000000L) ) {
+				gettimeofday(&tp, &tzp);
+				old_time = new_time;
+				CheckAPMEvents();
+			}
                 }       
                 
                 CheckX11Events();
